@@ -4,10 +4,9 @@ use strict;
 use warnings;
 use parent 'Exporter';
 use Test::More;
-use PAUSE::Permissions;
 use Parse::LocalDistribution;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 our @EXPORT = (@Test::More::EXPORT, qw/all_permissions_ok/);
 
@@ -25,14 +24,15 @@ sub all_permissions_ok {
   # Get authority from META
   my $meta_authority ||= _get_authority_in_meta();
 
-  # Prepare 06perms for testing
-  my $perms = PAUSE::Permissions->new;
-
   local $Parse::PMFile::ALLOW_DEV_VERSION = 1 if $opts->{dev};
 
   # Get packages (respecting no_index)
   my $provides = Parse::LocalDistribution->new->parse();
 
+  # Get maintainers from 06perms or MetaCPAN
+  my $use_metacpan = $opts->{metacpan} || $ENV{TEST_PAUSE_PERMISSIONS_METACPAN};
+  my $maintainers = _get_maintainers($use_metacpan, [keys %$provides]);
+
   # Iterate
   my $saw_errors;
   my @authorities = grep $_, $author, $meta_authority;
@@ -42,22 +42,21 @@ SKIP:
   for my $package (keys %$provides) {
     my $authority = uc($meta_authority || $author || '');
 
-    my $mp = $perms->module_permissions($package);
+    my $module_maintainers = $maintainers->{$package};
 
-    if (!$mp) {
+    if (!$module_maintainers) {
       pass "$package: no one has permissions ($authority should have the first come)";
       $new_packages{$package} = 1;
       next;
     }
-    my @module_maintainers = $mp->all_maintainers;
-    $dist_maintainers{uc $_} = 1 for @module_maintainers;
+    $dist_maintainers{uc $_} = 1 for @$module_maintainers;
 
     # Author should have permissions, regardless of the authority
-    if (grep { uc $_ eq uc $author } @module_maintainers) {
+    if (grep { uc $_ eq uc $author } @$module_maintainers) {
       pass "$package: $author has a permission";
     }
     else {
-      fail "$package: maintained by ".join ', ', @module_maintainers;
+      fail "$package: maintained by ".join ', ', @$module_maintainers;
       $saw_errors = 1;
     }
 
@@ -138,6 +137,31 @@ sub _get_authority_in_file {
   }
 }
 
+sub _get_maintainers {
+  my ($use_metacpan, $modules) = @_;
+  if ($use_metacpan) {
+    eval { require PAUSE::Permissions::MetaCPAN };
+    die "To use MetaCPAN permission API, "
+      . "you need to install PAUSE::Permissions::MetaCPAN, $@" if $@;
+    my $perms = PAUSE::Permissions::MetaCPAN->new->get(modules => $modules);
+    my %maintainers;
+    for my $module (@$modules) {
+      $maintainers{$module} = $perms->{$module}
+        ? [ $perms->{$module}{owner}, @{$perms->{$module}{co_maintainers}} ] : undef;
+    }
+    \%maintainers;
+  } else {
+    require PAUSE::Permissions;
+    my $file = PAUSE::Permissions->new;
+    my %maintainers;
+    for my $module (@$modules) {
+      my $mp = $file->module_permissions($module);
+      $maintainers{$module} = $mp ? [$mp->all_maintainers] : undef;
+    }
+    \%maintainers;
+  }
+}
+
 1;
 
 __END__
@@ -229,6 +253,15 @@ This module ignores modules that won't be indexed (namely those
 that have a version number with an underscore in it) by default.
 If you do want to test them, set C<dev> to true.
 
+=head3 use MetaCPAN API for testing permissions
+
+    all_permissions_ok({metacpan => 1});
+
+If C<metacpan> is true, this module tests permissions via MetaCPAN API
+instead of C<06perms.txt> using L<PAUSE::Permissions::MetaCPAN>.
+You can also set an environment variable C<TEST_PAUSE_PERMISSIONS_METACPAN> true
+to use MetaCPAN API.
+
 =head1 SEE ALSO
 
 L<PAUSE::Permissions>, L<App::PAUSE::CheckPerms>
